.. _vmware_scenarios:

****************************
Ansible for VMware Scenarios
****************************

Welcome to the Ansible for VMWare Guide!

The purpose of this guide is to teach you everything you need to know about using Ansible with VMWare.

To get started, please select one of the following topics.


.. toctree::
   :maxdepth: 2

   vmware_scenario_1

   